@@ -1,6 +1,6 @@
 __author__ = 'gsibble'
 
-class CoinBaseContact(object):
+class CoinbaseContact(object):
 
     def __init__(self, contact_id=None, name=None, email=None):
         self.id = contact_id
